searchData={"items":[{"type":"module","title":"Belp","doc":"Belp is a simple Boolean Expression Lexer and Parser.","ref":"Belp.html"},{"type":"function","title":"Belp.eval/2","doc":"Evaluates the given expression.","ref":"Belp.html#eval/2"},{"type":"function","title":"Examples - Belp.eval/2","doc":"iex> Belp.eval(\"foo and bar\", foo: true, bar: false)\n    {:ok, false}\n\n    iex> Belp.eval(\"foo or bar\", %{\"foo\" => true, \"bar\" => false})\n    {:ok, true}\n\n    iex> Belp.eval(\"bar\", %{foo: true})\n    {:error, %Belp.UndefinedVariableError{var: \"bar\"}}\n\n    iex> Belp.eval(\"invalid expression\")\n    {:error, %Belp.SyntaxError{line: 1, token: \"expression\"}}\n\n    iex> Belp.eval(\"foo || bar\")\n    {:error, %Belp.InvalidCharError{char: \"|\", line: 1}}","ref":"Belp.html#eval/2-examples"},{"type":"function","title":"Belp.eval!/2","doc":"Evaluates the given expression. Raises when the expression is invalid or\nvariables are undefined.","ref":"Belp.html#eval!/2"},{"type":"function","title":"Examples - Belp.eval!/2","doc":"iex> Belp.eval!(\"foo and bar\", foo: true, bar: false)\n    false\n\n    iex> Belp.eval!(\"foo or bar\", %{\"foo\" => true, \"bar\" => false})\n    true\n\n    iex> Belp.eval!(\"bar\", %{foo: true})\n    ** (Belp.UndefinedVariableError) Undefined variable: bar\n\n    iex> Belp.eval!(\"invalid expression\")\n    ** (Belp.SyntaxError) Syntax error near token \"expression\" on line 1\n\n    iex> Belp.eval!(\"foo || bar\")\n    ** (Belp.InvalidCharError) Invalid character \"|\" on line 1","ref":"Belp.html#eval!/2-examples"},{"type":"function","title":"Belp.valid_expression?/1","doc":"Checks whether the given expression is valid.","ref":"Belp.html#valid_expression?/1"},{"type":"function","title":"Examples - Belp.valid_expression?/1","doc":"iex> Belp.valid_expression?(\"foo and bar\")\n    true\n\n    iex> Belp.valid_expression?(\"invalid expression\")\n    false\n\n    iex> Belp.valid_expression?(\"foo || bar\")\n    false","ref":"Belp.html#valid_expression?/1-examples"},{"type":"function","title":"Belp.validate/1","doc":"Validates the given expression, returning an error tuple in case the\nexpression is invalid.","ref":"Belp.html#validate/1"},{"type":"function","title":"Examples - Belp.validate/1","doc":"iex> Belp.validate(\"foo and bar\")\n    :ok\n\n    iex> Belp.validate(\"invalid expression\")\n    {:error, %Belp.SyntaxError{line: 1, token: \"expression\"}}\n\n    iex> Belp.validate(\"foo || bar\")\n    {:error, %Belp.InvalidCharError{char: \"|\", line: 1}}","ref":"Belp.html#validate/1-examples"},{"type":"function","title":"Belp.variables/1","doc":"Gets a list of variable names that are present in the given expression.","ref":"Belp.html#variables/1"},{"type":"function","title":"Examples - Belp.variables/1","doc":"iex> Belp.variables(\"(foo and bar) or !foo\")\n    {:ok, [\"foo\", \"bar\"]}\n\n    iex> Belp.variables(\"invalid expression\")\n    {:error, %Belp.SyntaxError{line: 1, token: \"expression\"}}\n\n    iex> Belp.variables(\"foo || bar\")\n    {:error, %Belp.InvalidCharError{char: \"|\", line: 1}}","ref":"Belp.html#variables/1-examples"},{"type":"function","title":"Belp.variables!/1","doc":"Gets a list of variable names that are present in the given expression. Raises\nwhen the expression is invalid or variables are undefined.","ref":"Belp.html#variables!/1"},{"type":"function","title":"Examples - Belp.variables!/1","doc":"iex> Belp.variables!(\"(foo and bar) or !foo\")\n    [\"foo\", \"bar\"]\n\n    iex> Belp.variables!(\"invalid expression\")\n    ** (Belp.SyntaxError) Syntax error near token \"expression\" on line 1\n\n    iex> Belp.variables!(\"foo || bar\")\n    ** (Belp.InvalidCharError) Invalid character \"|\" on line 1","ref":"Belp.html#variables!/1-examples"},{"type":"type","title":"Belp.expr/0","doc":"A type that describes which primitives can be used as expression.","ref":"Belp.html#t:expr/0"},{"type":"exception","title":"Belp.InvalidCharError","doc":"An error that is returned or raised when a expression contains an invalid\nchar.","ref":"Belp.InvalidCharError.html"},{"type":"function","title":"Belp.InvalidCharError.message/1","doc":"","ref":"Belp.InvalidCharError.html#message/1"},{"type":"type","title":"Belp.InvalidCharError.t/0","doc":"","ref":"Belp.InvalidCharError.html#t:t/0"},{"type":"exception","title":"Belp.SyntaxError","doc":"An error that is returned or raised when the expression contains a syntax\nerror.","ref":"Belp.SyntaxError.html"},{"type":"function","title":"Belp.SyntaxError.message/1","doc":"","ref":"Belp.SyntaxError.html#message/1"},{"type":"type","title":"Belp.SyntaxError.t/0","doc":"","ref":"Belp.SyntaxError.html#t:t/0"},{"type":"exception","title":"Belp.UndefinedVariableError","doc":"An error that is returned or raised when a variable used in a expression is\nundefined.","ref":"Belp.UndefinedVariableError.html"},{"type":"function","title":"Belp.UndefinedVariableError.message/1","doc":"","ref":"Belp.UndefinedVariableError.html#message/1"},{"type":"type","title":"Belp.UndefinedVariableError.t/0","doc":"","ref":"Belp.UndefinedVariableError.html#t:t/0"},{"type":"extras","title":"Belp","doc":"# Belp\n\n[![Build](https://github.com/tlux/belp/actions/workflows/elixir.yml/badge.svg)](https://github.com/tlux/belp/actions/workflows/elixir.yml)\n[![Coverage Status](https://coveralls.io/repos/github/tlux/belp/badge.svg?branch=main)](https://coveralls.io/github/tlux/belp?branch=main)\n[![Module Version](https://img.shields.io/hexpm/v/belp.svg)](https://hex.pm/packages/belp)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/belp/)\n[![License](https://img.shields.io/hexpm/l/belp.svg)](https://github.com/tlux/belp/blob/main/LICENSE.md)\n[![Last Updated](https://img.shields.io/github/last-commit/tlux/belp.svg)](https://github.com/tlux/belp/commits/main)\n\nA simple *B*oolean *E*xpression *L*exer and *P*arser written in Elixir.","ref":"readme.html"},{"type":"extras","title":"Installation - Belp","doc":"The package can be installed by adding `belp` to your list of dependencies in\n`mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:belp, \"~> 1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Belp","doc":"```elixir\niex> Belp.eval!(\n...>   \"(foo or bar) and not baz\",\n...>   %{\"foo\" => false, \"bar\" => true, \"baz\" => false}\n...> )\ntrue\n```\n\n```elixir\niex> Belp.eval!(\"invalid expression\")\n** (Belp.SyntaxError) Syntax error near token \"expression\" on line 1\n```\n\nSee [HexDocs](https://hexdocs.pm/belp) for the full API.","ref":"readme.html#usage"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}